@@ -5,7 +5,7 @@ import numpy as np
 
 from .math_utils import get_cylindrical_velocities,get_cylindrical_coordinates,get_spherical_coordinates,get_spherical_velocities
 from .physics_utils import getTemperature
-from .cosmo_utils import getAgesGyrs,convertStellarAges
+from .cosmo_utils import RydenLookbackTime, getAgesGyrs
 
 def get_fnames(snapdir,snapnum,snapdir_name=''):
     fnames = [
@@ -146,6 +146,12 @@ def openSnapshot(
     ## let the user know what snapshot file we're trying to open
         if loud: print(fname)
         with h5py.File(fname,'r') as handle:
+            ## determine if the coordinates are in double precision, by default they are not
+            if ('Flag_DoublePrecision' in handle['Header'].attrs and 
+                handle['Header'].attrs['Flag_DoublePrecision']): 
+                coord_dtype = np.float64
+            else: coord_dtype = np.float32
+
             if i == 0:
                 ## read header once
                 if not no_header_keys: fillHeader(new_dictionary,handle)
@@ -171,11 +177,6 @@ def openSnapshot(
                 if 'PartType%d'%ptype not in handle: continue
                 ## load snapshot data
                 if not header_only:
-                    ## decide if the coordinates are in double precision, by default they are not
-                    if ('Flag_DoublePrecision' in new_dictionary and 
-                        new_dictionary['Flag_DoublePrecision']): coord_dtype = np.float64
-                    else: coord_dtype = np.float32
-
                     ## initialize particle arrays
                     for pkey in handle['PartType%d'%ptype].keys():
                         if (
@@ -292,10 +293,9 @@ def openSnapshot(
                 Omega0 = new_dictionary['Omega0']
             else:
                 Omega0 = new_dictionary['Omega_Matter']
-            new_dictionary['TimeGyr'] = convertStellarAges(
+            new_dictionary['TimeGyr'] = RydenLookbackTime(
                 new_dictionary['HubbleParam'],
                 Omega0,
-                1e-12,
                 new_dictionary['Time'])
             new_dictionary['ScaleFactor'] = new_dictionary['Time']
         else:
